@@ -904,6 +904,13 @@ ctrLoadQueryIntoDbCtgov <- function(
          call. = FALSE)
   }
   #
+  if (!suppressWarnings(
+    installFindBinary(
+      commandtest = "php -r 'json_encode(\"<foo>\");'"))) {
+    stop("php json not found, ctrLoadQueryIntoDb() will not work.",
+         call. = FALSE)
+  }
+  #
   message("done.")
 
   # prepare a file handle for temporary directory
@@ -1149,6 +1156,14 @@ ctrLoadQueryIntoDbEuctr <- function(
          call. = FALSE)
   }
   #
+  if (euctrresults &&
+      !suppressWarnings(
+        installFindBinary(
+          commandtest = "php -r 'json_encode(\"<foo>\");'"))) {
+    stop("php json not found, ctrLoadQueryIntoDb() will not work.",
+         call. = FALSE)
+  }
+  #
   if (!suppressWarnings(installFindBinary(
     commandtest = "echo x | sed s/x/y/"))) {
     stop("sed not found, ctrLoadQueryIntoDb() will not work.",
