@@ -1,6 +1,7 @@
 ## RH 2019-09-28
 
 #### SETUP ####
+if(!at_home()) exit_file("skipping")
 source("setup_ctrdata.R")
 
 if (!check_mongo_remote_rw()) exit_file("Not available: remote rw MongoDB")
@@ -17,8 +18,9 @@ dbc <- nodbi::src_mongo(
 source("ctrdata_euctr.R", local = TRUE)
 
 #### close ####
-dbc$con$drop()
-dbc$con$disconnect()
-
-
+try({
+  dbc$con$drop()
+  dbc$con$disconnect()
+},
+silent = TRUE)
 
